@@ -17,7 +17,7 @@
 #ifndef KBBMAINWINDOW_CWSEARCHWIDGET_H
 #define KBBMAINWINDOW_CWSEARCHWIDGET_H
  
-#include "cwsearchwidget_base.h"
+#include "ui_cwsearchwidget_base.h"
 
 namespace KBugBusterMainWindow
 {
@@ -25,12 +25,22 @@ namespace KBugBusterMainWindow
 /**
  * @author Martijn Klingens
  */
+
+class CWSearchWidget_Base : public QWidget, public Ui::CWSearchWidget_Base
+{
+public:
+  CWSearchWidget_Base( QWidget *parent ) : QWidget( parent ) {
+    setupUi( this );
+  }
+};
+
+    
 class CWSearchWidget : public CWSearchWidget_Base
 {
     Q_OBJECT
 
 public:
-    CWSearchWidget( QWidget* parent = 0, const char* name = 0 );
+    CWSearchWidget( QWidget* parent = 0 );
     ~CWSearchWidget();
 
 public slots:
