@@ -1,5 +1,5 @@
 /* This file is part of KCachegrind.
-   Copyright (C) 2002 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
+   Copyright (C) 2002 - 2007 Josef Weidendorfer <Josef.Weidendorfer@gmx.de>
 
    KCachegrind is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -12,8 +12,8 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
@@ -23,27 +23,31 @@
 #ifndef LOADER_H
 #define LOADER_H
 
-#include <qobject.h>
-#include <qptrlist.h>
-#include <qstring.h>
+#include <QObject>
+#include <QList>
+#include <QString>
 
 class QFile;
-class TraceData;
 class TracePart;
 class Loader;
 
 
-typedef QPtrList<Loader> LoaderList;
-
 /**
- * To implement a new loader, inherit from the Loader class
- * and implement canLoadTrace(), loadTrace() and if a trace in
- * this format can consist out of multiple parts, implement
- * isPartOfTrace(), too.
+ * To implement a new loader, inherit from the Loader class and
+ * and reimplement canLoadTrace() and loadTrace().
+ *
  * For registration, put into the static initLoaders() function
  * of this base class a _loaderList.append(new MyLoader()).
  *
- * KCachegrind will use the first matching loader.
+ * KCachegrind will use the first loader matching according to
+ * canLoadTrace().
+ *
+ * The signals loadError() and loadWarning() can be emitted within
+ * loadTrace() to signal problems when loading the file.
+ * According messages are just shown as warnings or errors to the
+ * user, but do not show real failure, as even errors can be
+ * recoverable. For unablility to load a file, return false in
+ * loadTrace().
  */
 
 class Loader: public QObject
@@ -51,14 +55,15 @@ class Loader: public QObject
     Q_OBJECT
 
 public:
-  Loader(QString name, QString desc);
+  Loader(const QString& name, const QString& desc);
   virtual ~Loader();
 
+  // reimplement for a specific Loader
   virtual bool canLoadTrace(QFile* file);
   virtual bool loadTrace(TracePart*);
 
   static Loader* matchingLoader(QFile* file);
-  static Loader* loader(QString name);
+  static Loader* loader(const QString& name);
   static void initLoaders();
   static void deleteLoaders();
 
@@ -66,12 +71,14 @@ public:
   QString description() const { return _description; }
 
 signals:
-  void updateStatus(QString, int);
+  void updateStatus(const QString& statusmsg, int progress);
+  void loadError(const QString& filename, int line, const QString& msg);
+  void loadWarning(const QString& filename, int line, const QString& msg);
 
 private:
   QString _name, _description;
 
-  static LoaderList _loaderList;
+  static QList<Loader*> _loaderList;
 };
 
 
