@@ -12,24 +12,25 @@
 
    You should have received a copy of the GNU General Public License
    along with this program; see the file COPYING.  If not, write to
-   the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
-   Boston, MA 02111-1307, USA.
+   the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+   Boston, MA 02110-1301, USA.
 */
 
 /*
  * Part View
  */
 
-#include <qwhatsthis.h>
-#include <qpopupmenu.h>
-#include <qheader.h>
+
+#include "partview.h"
+
+#include <Qt3Support/Q3PopupMenu>
+#include <Qt3Support/Q3Header>
+
 #include <klocale.h>
 
 #include "configuration.h"
 #include "partlistitem.h"
 #include "toplevel.h"
-#include "partview.h"
-
 
 
 //
@@ -39,7 +40,7 @@
 
 PartView::PartView(TraceItemView* parentView,
 		   QWidget* parent, const char* name)
-  : QListView(parent, name), TraceItemView(parentView)
+  : Q3ListView(parent, name), TraceItemView(parentView)
 {
     _inSelectionUpdate = false;
 
@@ -62,10 +63,10 @@ PartView::PartView(TraceItemView* parentView,
 	     SLOT( selectionChangedSlot() ) );
 
     connect( this,
-	     SIGNAL(contextMenuRequested(QListViewItem*, const QPoint &, int)),
-	     SLOT(context(QListViewItem*, const QPoint &, int)));
+	     SIGNAL(contextMenuRequested(Q3ListViewItem*, const QPoint &, int)),
+	     SLOT(context(Q3ListViewItem*, const QPoint &, int)));
 
-    QWhatsThis::add( this, whatsThis() );
+    this->setWhatsThis( whatsThis() );
 }
 
 QString PartView::whatsThis() const
@@ -96,15 +97,15 @@ QString PartView::whatsThis() const
 }
 
 
-void PartView::context(QListViewItem* i, const QPoint & pos, int)
+void PartView::context(Q3ListViewItem* i, const QPoint & pos, int)
 {
-  QPopupMenu popup;
+  Q3PopupMenu popup;
 
   TracePart* p = i ? ((PartListItem*) i)->part() : 0;
 
   if (p) {
-    popup.insertItem(i18n("Select '%1'").arg(p->name()), 93);
-    popup.insertItem(i18n("Hide '%1'").arg(p->name()), 94);
+    popup.insertItem(i18n("Select '%1'", p->name()), 93);
+    popup.insertItem(i18n("Hide '%1'", p->name()), 94);
     popup.insertSeparator();
   }
 
@@ -116,10 +117,8 @@ void PartView::context(QListViewItem* i, const QPoint & pos, int)
 
   int r = popup.exec(pos);
   if (r == 95) {
-    ;
+    // TODO: ...
   }
-
-  // TODO: ...
 }
 
 void PartView::selectionChangedSlot()
@@ -127,40 +126,40 @@ void PartView::selectionChangedSlot()
     if (_inSelectionUpdate) return;
 
     TracePartList l;
-    QListViewItem* item  = firstChild();
+    Q3ListViewItem* item  = firstChild();
     for(;item;item = item->nextSibling())
       if (item->isSelected())
         l.append( ((PartListItem*)item)->part() );
 
-    selected(l);
+    partsSelected(l);
 }
 
 
 TraceItem* PartView::canShow(TraceItem* i)
 {
-  if (!data()) return 0;
-  if (data()->parts().count()>1) return i;
+  if (!TraceItemView::data()) return 0;
+  if (TraceItemView::data()->parts().count()>1) return i;
   return 0;
 }
 
 void PartView::doUpdate(int changeType)
 {
     // Special case ?
-    if (changeType == costType2Changed) return;
+    if (changeType == eventType2Changed) return;
     if (changeType == selectedItemChanged) return;
 
     if (changeType == groupTypeChanged) {
-	QListViewItem *item;
+	Q3ListViewItem *item;
 	for (item = firstChild();item;item = item->nextSibling())
 	    ((PartListItem*)item)->setGroupType(_groupType);
 
 	return;
     }
 
-    if (changeType == costTypeChanged) {
-	QListViewItem *item;
+    if (changeType == eventTypeChanged) {
+	Q3ListViewItem *item;
 	for (item = firstChild();item;item = item->nextSibling())
-	  ((PartListItem*)item)->setCostType(_costType);
+	  ((PartListItem*)item)->setCostType(_eventType);
 
 	return;
     }
@@ -169,7 +168,7 @@ void PartView::doUpdate(int changeType)
 
       TracePart* part;
 
-      QListViewItem* item;
+      Q3ListViewItem* item;
       _inSelectionUpdate = true;
       item  = firstChild();
       for(;item;item = item->nextSibling()) {
@@ -212,10 +211,10 @@ void PartView::refresh()
 
     _inSelectionUpdate = true;
 
-    QListViewItem* item = 0;
+    Q3ListViewItem* item = 0;
     for (part = allParts.first(); part; part = allParts.next()) {
 	if (hidden.findRef(part)>=0) continue;
-	item = new PartListItem(this, f, _costType, _groupType, part);
+	item = new PartListItem(this, f, _eventType, _groupType, part);
 
 	if (part->isActive()) {
 	    setSelected(item, true);
