@@ -2,10 +2,10 @@
                                 kompare_part.cpp
                                 ----------------
         begin                   : Sun Mar 4 2001
-        Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2005,2009 Otto Bruggeman <bruggie@gmail.com>
         Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
         Copyright 2004      Jeff Snyder    <jeff@caffeinated.me.uk>
-        Copyright 2007-2008 Kevin Kofler   <kevin.kofler@chello.at>
+        Copyright 2007-2009 Kevin Kofler   <kevin.kofler@chello.at>
 ****************************************************************************/
 
 /***************************************************************************
@@ -30,11 +30,12 @@
 #include <klocale.h>
 #include <kmessagebox.h>
 #include <kstandardaction.h>
+#include <kstandarddirs.h>
 #include <kstandardshortcut.h>
 #include <kcomponentdata.h>
 #include <ktemporaryfile.h>
 #include <kparts/genericfactory.h>
-//#include <ktempdir.h>
+#include <ktempdir.h>
 
 #include <kio/netaccess.h>
 #include <kglobal.h>
@@ -71,8 +72,16 @@ KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QStringL
 
 	readProperties( KGlobal::config().data() );
 
+	m_splitter = new KompareSplitter ( m_viewSettings, parentWidget );
+
+	// !!! Do not change this ->parentWidget()! Due to the bizarre reparenting hacks in KompareSplitter, !!!
+	// !!! the ->parentWidget() is not the one passed in the constructor, but the scroll view created    !!!
+	// !!! within the KompareSplitter. If you use m_splitter here, the scroll bars will not be shown!    !!!
+	// !!! Using the parentWidget parameter is also wrong, of course, you have to use m_splitter->...!   !!!
+	setWidget( m_splitter->parentWidget() );
+
 	// This creates the "Model creator" and connects the signals and slots
-	m_modelList = new Diff2::KompareModelList( m_diffSettings, m_info, this, "komparemodellist" );
+	m_modelList = new Diff2::KompareModelList( m_diffSettings, m_splitter, this, "komparemodellist" );
 	connect( m_modelList, SIGNAL(status( Kompare::Status )),
 	         this, SLOT(slotSetStatus( Kompare::Status )) );
 	connect( m_modelList, SIGNAL(setStatusBarModelInfo( int, int, int, int, int )),
@@ -114,9 +123,9 @@ KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QStringL
 	connect( m_modelList, SIGNAL(diffString(const QString&)),
 	         this, SIGNAL(diffString(const QString&)) );
 
-	// This creates the splitterwidget and connects the signals and slots
-	m_splitter = new KompareSplitter ( m_viewSettings, parentWidget );
+	connect( this, SIGNAL(kompareInfo(Kompare::Info*)), m_modelList, SLOT(slotKompareInfo(Kompare::Info*)) );
 
+	// Here we connect the splitter to the modellist
 	connect( m_modelList, SIGNAL(setSelection(const Diff2::DiffModel*, const Diff2::Difference*)),
 	         m_splitter,  SLOT(slotSetSelection(const Diff2::DiffModel*, const Diff2::Difference*)) );
 //	connect( m_splitter,  SIGNAL(selectionChanged(const Diff2::Difference*, const Diff2::Difference*)),
@@ -134,9 +143,6 @@ KomparePart::KomparePart( QWidget *parentWidget, QObject *parent, const QStringL
 	         m_splitter, SLOT(slotApplyDifference(const Diff2::Difference*, bool)) );
 	connect( this, SIGNAL(configChanged()), m_splitter, SIGNAL(configChanged()) );
 
-	// notify the part that this is our internal widget
-	setWidget( m_splitter->parentWidget() );
-
 	setupActions();
 
 	// set our XML-UI resource file
@@ -197,12 +203,13 @@ bool KomparePart::openDiff( const KUrl& url )
 {
 	kDebug(8103) << "Url = " << url.url() << endl;
 
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ShowingDiff;
 	m_info.source = url;
 	bool result = false;
-	m_info.localSource = fetchURL( url );
+	fetchURL( url, true );
+
+	emit kompareInfo( &m_info );
+
 	if ( !m_info.localSource.isEmpty() )
 	{
 		kDebug(8103) << "Download succeeded " << endl;
@@ -223,10 +230,10 @@ bool KomparePart::openDiff( const QString& diffOutput )
 {
 	bool value = false;
 
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ShowingDiff;
 
+	emit kompareInfo( &m_info );
+
 	if ( m_modelList->parseDiffOutput( diffOutput ) == 0 )
 	{
 		value = true;
@@ -242,7 +249,7 @@ bool KomparePart::openDiff( const QString& diffOutput )
 bool KomparePart::openDiff3( const KUrl& diff3Url )
 {
 	// FIXME: Implement this !!!
-	kDebug(8103) << "Not implemented yet. Filename is: " << diff3Url.url() << endl;
+	kDebug(8103) << "Not implemented yet. Filename is: " << diff3Url.prettyUrl() << endl;
 	return false;
 }
 
@@ -260,99 +267,184 @@ bool KomparePart::exists( const QString& url )
 	return fi.exists();
 }
 
-const QString KomparePart::fetchURL( const KUrl& url )
+bool KomparePart::fetchURL( const KUrl& url, bool addToSource )
 {
+	// Default value if there is an error is "", we rely on it!
 	QString tempFileName( "" );
+	// Only in case of error do we set result to false, don't forget!!
+	bool result = true;
+	KTempDir* tmpDir = 0;
+
 	if ( !url.isLocalFile() )
 	{
-		if ( ! KIO::NetAccess::download( url, tempFileName, widget() ) )
+		KIO::UDSEntry node;
+		KIO::NetAccess::stat( url, node, widget() );
+		if ( !node.isDir() )
 		{
-			slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
-			tempFileName = "";
+			if ( ! KIO::NetAccess::download( url, tempFileName, widget() ) )
+			{
+				slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
+				tempFileName = ""; // Not sure if download has already touched this tempFileName when there is an error
+				result = false;
+			}
+		}
+		else
+		{
+			tmpDir = new KTempDir(KStandardDirs::locateLocal("tmp", "kompare"));
+			tmpDir->setAutoRemove( true ); // Yes this is the default but just to make sure
+			if ( ! KIO::NetAccess::dircopy( url, KUrl( tmpDir->name() ), widget() ) )
+			{
+				slotShowError( i18n( "<qt>The URL <b>%1</b> cannot be downloaded.</qt>", url.prettyUrl() ) );
+				delete tmpDir;
+				tmpDir = 0;
+				result = false;
+			}
+			else
+			{
+				tempFileName = tmpDir->name();
+				kDebug(8101) << "tempFileName = " << tempFileName << endl;
+				// If a directory is copied into KTempDir then the directory in 
+				// here is what I need to add to tempFileName
+				QDir dir( tempFileName );
+				QStringList entries = dir.entryList( QDir::Dirs | QDir::NoDotAndDotDot );
+				if ( entries.size() == 1 ) // More than 1 entry in here means big problems!!!
+				{
+					if ( !tempFileName.endsWith( '/' ) )
+						tempFileName += '/';
+					tempFileName += entries.at( 0 );
+					tempFileName += '/';
+				}
+				else
+				{
+					kDebug(8101) << "Yikes, nothing downloaded?" << endl;
+					delete tmpDir;
+					tmpDir = 0;
+					tempFileName = "";
+					result = false;
+				}
+			}
 		}
-		return tempFileName;
 	}
 	else
 	{
 		// is Local already, check if exists
 		if ( exists( url.path() ) )
-			return url.path();
+			tempFileName = url.path();
 		else
 		{
 			slotShowError( i18n( "<qt>The URL <b>%1</b> does not exist on your system.</qt>", url.prettyUrl() ) );
-			return tempFileName;
+			result = false;
 		}
 	}
+
+	if ( addToSource )
+	{
+		m_info.localSource = tempFileName;
+		m_info.sourceKTempDir = tmpDir;
+	}
+	else
+	{
+		m_info.localDestination = tempFileName;
+		m_info.destinationKTempDir = tmpDir;
+	}
+
+	return result;
 }
 
 void KomparePart::cleanUpTemporaryFiles()
 {
-	// i hope a local file will not be removed if it was not downloaded...
+	kDebug(8101) << "Cleaning temporary files." << endl;
 	if ( !m_info.localSource.isEmpty() )
-		KIO::NetAccess::removeTempFile( m_info.localSource );
+	{
+		if ( m_info.sourceKTempDir == 0 )
+			KIO::NetAccess::removeTempFile( m_info.localSource );
+		else
+		{
+			delete m_info.sourceKTempDir;
+			m_info.sourceKTempDir = 0;
+		}
+		m_info.localSource = "";
+	}
 	if ( !m_info.localDestination.isEmpty() )
-		KIO::NetAccess::removeTempFile( m_info.localDestination );
+	{
+		if ( m_info.destinationKTempDir == 0  )
+			KIO::NetAccess::removeTempFile( m_info.localDestination );
+		else
+		{
+			delete m_info.destinationKTempDir;
+			m_info.destinationKTempDir = 0;
+		}
+		m_info.localDestination = "";
+	}
 }
 
 void KomparePart::compare( const KUrl& source, const KUrl& destination )
 {
+	// FIXME: This is silly, i can use NetAccess::stat to figure out what it is and not
+	// wait until i am in the modellist to determine the mode we're supposed to be in.
+	// That should make the code more readable
+	// I should store the KTempDir(s)/File(s) in the Info struct as well and delete it at the right time
 	m_info.source = source;
 	m_info.destination = destination;
 
-	m_info.localSource = fetchURL( source );
-	m_info.localDestination = fetchURL( destination );
+	// FIXME: (Not urgent) But turn this into an enum, for now i cant find a nice name for the enum that has Source and Destination as values
+	// For now we do not do error checking, user has already been notified and if the localString is empty then we dont diff
+	fetchURL( source, true );
+	fetchURL( destination, false );
 
 	emit kompareInfo( &m_info );
 
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->compare( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->compare();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
 void KomparePart::compareFiles( const KUrl& sourceFile, const KUrl& destinationFile )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ComparingFiles;
 
 	m_info.source = sourceFile;
 	m_info.destination = destinationFile;
 
-	m_info.localSource = fetchURL( sourceFile );
-	m_info.localDestination = fetchURL( destinationFile );
+	// FIXME: (Not urgent) But turn this into an enum, for now i cant find a nice name for the enum that has Source and Destination as values
+	// For now we do not do error checking, user has already been notified and if the localString is empty then we dont diff
+	fetchURL( sourceFile, true );
+	fetchURL( destinationFile, false );
+
+	emit kompareInfo( &m_info );
 
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->compareFiles( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->compareFiles();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
 void KomparePart::compareDirs( const KUrl& sourceDirectory, const KUrl& destinationDirectory )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.mode = Kompare::ComparingDirs;
 
 	m_info.source = sourceDirectory;
 	m_info.destination = destinationDirectory;
 
-	m_info.localSource = fetchURL( sourceDirectory );
-	m_info.localDestination = fetchURL( destinationDirectory );
+	fetchURL( sourceDirectory, true );
+	fetchURL( destinationDirectory, false );
+
+	emit kompareInfo( &m_info );
 
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->compareDirs( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->compareDirs();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
 void KomparePart::compare3Files( const KUrl& /*originalFile*/, const KUrl& /*changedFile1*/, const KUrl& /*changedFile2*/ )
@@ -365,38 +457,38 @@ void KomparePart::compare3Files( const KUrl& /*originalFile*/, const KUrl& /*cha
 
 void KomparePart::openFileAndDiff( const KUrl& file, const KUrl& diffFile )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.source = file;
 	m_info.destination = diffFile;
 
-	m_info.localSource = fetchURL( file );
-	m_info.localDestination = fetchURL( diffFile );
+	fetchURL( file, true );
+	fetchURL( diffFile, false );
 	m_info.mode = Kompare::BlendingFile;
 
+	emit kompareInfo( &m_info );
+
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->openFileAndDiff( m_info.localSource, m_info.localDestination );
-		updateActions();
+		m_modelList->openFileAndDiff();
 		updateCaption();
 		updateStatus();
 	}
+	updateActions();
 }
 
 void KomparePart::openDirAndDiff ( const KUrl& dir,  const KUrl& diffFile )
 {
-	emit kompareInfo( &m_info );
-
 	m_info.source = dir;
 	m_info.destination = diffFile;
 
-	m_info.localSource = fetchURL( dir );
-	m_info.localDestination = fetchURL( diffFile );
+	fetchURL( dir, true );
+	fetchURL( diffFile, false );
 	m_info.mode = Kompare::BlendingDir;
 
+	emit kompareInfo( &m_info );
+
 	if ( !m_info.localSource.isEmpty() && !m_info.localDestination.isEmpty() )
 	{
-		m_modelList->openDirAndDiff( m_info.localSource, m_info.localDestination );
+		m_modelList->openDirAndDiff();
 		updateActions();
 		updateCaption();
 		updateStatus();
@@ -422,19 +514,19 @@ bool KomparePart::saveAll()
 
 void KomparePart::saveDiff()
 {
-	KDialog* dlg = new KDialog( widget() );
-	dlg->setName( "save_options" );
-	dlg->setModal( true );
-	dlg->setWindowTitle( i18n("Diff Options") );
-	dlg->setButtons( KDialog::Ok|KDialog::Cancel );
+	KDialog dlg( widget() );
+	dlg.setName( "save_options" );
+	dlg.setModal( true );
+	dlg.setWindowTitle( i18n("Diff Options") );
+	dlg.setButtons( KDialog::Ok|KDialog::Cancel );
 	KompareSaveOptionsWidget* w = new KompareSaveOptionsWidget(
 	                                             m_info.localSource,
 	                                             m_info.localDestination,
-	                                             m_diffSettings, dlg );
-	dlg->setMainWidget( w );
-	dlg->setButtonGuiItem( KDialog::Ok, KStandardGuiItem::save() );
+	                                             m_diffSettings, &dlg );
+	dlg.setMainWidget( w );
+	dlg.setButtonGuiItem( KDialog::Ok, KStandardGuiItem::save() );
 
-	if( dlg->exec() ) {
+	if( dlg.exec() ) {
 		w->saveOptions();
 		KSharedConfig::Ptr config = componentData().config();
 		saveProperties( config.data() );
@@ -476,14 +568,13 @@ void KomparePart::saveDiff()
 			}
 		}
 	}
-	delete dlg;
 }
 
-KAboutData *KomparePart::createAboutData()
+KAboutData* KomparePart::createAboutData()
 {
-    KAboutData *about = new KAboutData("kompare", 0, ki18n("KomparePart"), "3.2");
+    KAboutData *about = new KAboutData("kompare", 0, ki18n("KomparePart"), "4.0");
     about->addAuthor(ki18n("John Firebaugh"), ki18n("Author"), "jfirebaugh@kde.org");
-    about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "otto.bruggeman@home.nl" );
+    about->addAuthor(ki18n("Otto Bruggeman"), ki18n("Author"), "bruggie@gmail.com" );
     return about;
 }
 
@@ -523,7 +614,7 @@ void KomparePart::updateCaption()
 	case Kompare::ComparingDirs :
 	case Kompare::BlendingFile :
 	case Kompare::BlendingDir :
-		text = source + ':' + destination;
+		text = source + " -- " + destination; // no need to translate this " -- "
 		break;
 	case Kompare::ShowingDiff :
 		text = source;
@@ -601,13 +692,7 @@ void KomparePart::slotSwap()
 	}
 
 	// Swap the info in the Kompare::Info struct
-	KUrl url = m_info.source;
-	m_info.source = m_info.destination;
-	m_info.destination = url;
-
-	QString string = m_info.localSource;
-	m_info.localSource = m_info.localDestination;
-	m_info.localDestination = string;
+	m_info.swapSourceWithDestination();
 
 	// Update window caption and statusbar text
 	updateCaption();
@@ -630,13 +715,17 @@ void KomparePart::slotRefreshDiff()
 		                KStandardGuiItem::discard()
 		            );
 
+		if ( query == KMessageBox::Cancel )
+			return; // Abort prematurely so no refreshing
+
 		if ( query == KMessageBox::Yes )
 			m_modelList->saveAll();
-
-		if ( query == KMessageBox::Cancel )
-			return; // Abort prematurely so no swapping
 	}
 
+	// For this to work properly you have to refetch the files from their (remote) locations
+	cleanUpTemporaryFiles();
+	fetchURL( m_info.source, true );
+	fetchURL( m_info.destination, false );
 	m_modelList->refresh();
 }
 
@@ -768,13 +857,12 @@ int KomparePart::saveProperties( KConfig *config )
 void KomparePart::optionsPreferences()
 {
 	// show preferences
-	KomparePrefDlg* pref = new KomparePrefDlg( m_viewSettings, m_diffSettings );
+	KomparePrefDlg pref( m_viewSettings, m_diffSettings );
 
-	connect( pref, SIGNAL(applyClicked()), this, SIGNAL(configChanged()) );
+	connect( &pref, SIGNAL(configChanged()), this, SIGNAL(configChanged()) );
 
-	if ( pref->exec() )
+	if ( pref.exec() )
 		emit configChanged();
-        delete pref;
 }
 
 void KomparePart::slotSetModified( bool modified )
