@@ -2,7 +2,7 @@
                                 kompare_part.h
                                 --------------
         begin                   : Sun Mar 4 2001
-        Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+        Copyright 2001-2005,2009 Otto Bruggeman <bruggie@gmail.com>
         Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
         Copyright 2004      Jeff Snyder    <jeff@caffeinated.me.uk>
         Copyright 2007-2008 Kevin Kofler   <kevin.kofler@chello.at>
@@ -197,7 +197,9 @@ private:
 	void setupActions();
 	bool exists( const QString& url );
 	bool isDirectory( const KUrl& url );
-	const QString fetchURL( const KUrl& url );
+	// FIXME (like in cpp file not urgent) Replace with enum, cant find a proper 
+	// name now but it is private anyway so can not be used from outside
+	bool fetchURL( const KUrl& url, bool isSource );
 
 private:
 	// Uhm why were these static again ???
@@ -216,7 +218,7 @@ private:
 	KAction*                 m_diffStats;
 	KAction*                 m_diffRefresh;
 
-	KTemporaryFile*               m_tempDiff;
+	KTemporaryFile*          m_tempDiff;
 
 	struct Kompare::Info     m_info;
 };
