@@ -2,9 +2,9 @@
                           komparemodellist.cpp
                           --------------------
     begin                : Tue Jun 26 2001
-    Copyright 2001-2004 Otto Bruggeman <otto.bruggeman@home.nl>
+    Copyright 2001-2005,2009 Otto Bruggeman <otto.bruggeman@home.nl>
     Copyright 2001-2003 John Firebaugh <jfirebaugh@kde.org>
-    Copyright 2007-2008 Kevin Kofler   <kevin.kofler@chello.at>
+    Copyright 2007-2009 Kevin Kofler   <kevin.kofler@chello.at>
  ***************************************************************************/
 
 /***************************************************************************
@@ -46,7 +46,7 @@
 
 using namespace Diff2;
 
-KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::Info& info, QObject* parent, const char* name )
+KompareModelList::KompareModelList( DiffSettings* diffSettings, QWidget* widgetForKIO, QObject* parent, const char* name )
 	: QObject( parent, name ),
 	m_diffProcess( 0 ),
 	m_diffSettings( diffSettings ),
@@ -55,9 +55,11 @@ KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::
 	m_selectedDifference( 0 ),
 	m_noOfModified( 0 ),
 	m_modelIndex( 0 ),
-	m_info( info ),
-	m_textCodec( 0 )
+	m_info( 0 ),
+	m_textCodec( 0 ),
+	m_widgetForKIO( widgetForKIO )
 {
+	kDebug(8101) << "Show me the arguments: " << diffSettings << ", " << widgetForKIO << ", " << parent << ", " << name << endl;
 	KActionCollection *ac = (( KomparePart* )parent)->actionCollection();
 	m_applyDifference = ac->addAction( "difference_apply", this, SLOT(slotActionApplyDifference()) );
 	m_applyDifference->setIcon( KIcon("arrow-right") );
@@ -102,6 +104,10 @@ KompareModelList::KompareModelList( DiffSettings* diffSettings, struct Kompare::
 
 KompareModelList::~KompareModelList()
 {
+	m_selectedModel = 0;
+	m_selectedDifference = 0;
+	m_info = 0;
+	delete m_models;
 }
 
 bool KompareModelList::isDirectory( const QString& url ) const
@@ -121,27 +127,27 @@ bool KompareModelList::isDiff( const QString& mimeType ) const
 		return false;
 }
 
-bool KompareModelList::compare( const QString& source, const QString& destination )
+bool KompareModelList::compare()
 {
 	bool result = false;
 
-	bool sourceIsDirectory = isDirectory( source );
-	bool destinationIsDirectory = isDirectory( source );
+	bool sourceIsDirectory = isDirectory( m_info->localSource );
+	bool destinationIsDirectory = isDirectory( m_info->localDestination );
 
 	if ( sourceIsDirectory && destinationIsDirectory )
 	{
-		m_info.mode = Kompare::ComparingDirs;
-		result = compareDirs( source, destination );
+		m_info->mode = Kompare::ComparingDirs;
+		result = compareDirs();
 	}
 	else if ( !sourceIsDirectory && !destinationIsDirectory )
 	{
-		QFile sourceFile( source );
+		QFile sourceFile( m_info->localSource );
 		sourceFile.open( QIODevice::ReadOnly );
 		QString sourceMimeType = ( KMimeType::findByContent( sourceFile.readAll() ) )->name();
 		sourceFile.close();
 		kDebug(8101) << "Mimetype source     : " << sourceMimeType << endl;
 
-		QFile destinationFile( destination );
+		QFile destinationFile( m_info->localDestination );
 		destinationFile.open( QIODevice::ReadOnly );
 		QString destinationMimeType = ( KMimeType::findByContent( destinationFile.readAll() ) )->name();
 		destinationFile.close();
@@ -151,41 +157,46 @@ bool KompareModelList::compare( const QString& source, const QString& destinatio
 		if ( !isDiff( sourceMimeType ) && isDiff( destinationMimeType ) )
 		{
 			kDebug(8101) << "Blending destination into source..." << endl;
-			m_info.mode = Kompare::BlendingFile;
-			result = openFileAndDiff( source, destination );
+			m_info->mode = Kompare::BlendingFile;
+			result = openFileAndDiff();
 		}
 		else if ( isDiff( sourceMimeType ) && !isDiff( destinationMimeType ) )
 		{
 			kDebug(8101) << "Blending source into destination..." << endl;
-			m_info.mode = Kompare::BlendingFile;
-			result = openFileAndDiff( destination, source );
+			m_info->mode = Kompare::BlendingFile;
+			// Swap source and destination before calling this
+			m_info->swapSourceWithDestination();
+			// Do we need to notify anyone we swapped source and destination?
+			// No we do not need to notify anyone about swapping source with destination
+			result = openFileAndDiff();
 		}
 		else
 		{
 			kDebug(8101) << "Comparing source with destination" << endl;
-			m_info.mode = Kompare::ComparingFiles;
-			result = compareFiles( source, destination );
+			m_info->mode = Kompare::ComparingFiles;
+			result = compareFiles();
 		}
 	}
 	else if ( sourceIsDirectory && !destinationIsDirectory )
 	{
-		m_info.mode = Kompare::BlendingDir;
-		result = openDirAndDiff( source, destination );
+		m_info->mode = Kompare::BlendingDir;
+		result = openDirAndDiff();
 	}
 	else
 	{
-		m_info.mode = Kompare::BlendingDir;
-		result = openDirAndDiff( destination, source );
+		m_info->mode = Kompare::BlendingDir;
+		// Swap source and destination first in m_info
+		m_info->swapSourceWithDestination();
+		// Do we need to notify anyone we swapped source and destination?
+		// No we do not need to notify anyone about swapping source with destination
+		result = openDirAndDiff();
 	}
 
 	return result;
 }
 
-bool KompareModelList::compareFiles( const QString& source, const QString& destination )
+bool KompareModelList::compareFiles()
 {
-	m_source = source;
-	m_destination = destination;
-
 	clear(); // Destroy the old models...
 
 //	m_fileWatch = new KDirWatch( this, "filewatch" );
@@ -197,7 +208,7 @@ bool KompareModelList::compareFiles( const QString& source, const QString& desti
 //	connect( m_fileWatch, SIGNAL( deleted( const QString& ) ), this, SLOT( slotFileChanged( const QString& ) ) );
 
 //	m_fileWatch->startScan();
-	m_diffProcess = new KompareProcess( m_diffSettings, Kompare::Custom, m_source, m_destination );
+	m_diffProcess = new KompareProcess( m_diffSettings, Kompare::Custom, m_info->localSource, m_info->localDestination );
 	m_diffProcess->setEncoding( m_encoding );
 
 	connect( m_diffProcess, SIGNAL(diffHasFinished( bool )),
@@ -209,11 +220,8 @@ bool KompareModelList::compareFiles( const QString& source, const QString& desti
 	return true;
 }
 
-bool KompareModelList::compareDirs( const QString& source, const QString& destination )
+bool KompareModelList::compareDirs()
 {
-	m_source = source;
-	m_destination = destination;
-
 	clear(); // Destroy the old models...
 
 //	m_dirWatch = new KDirWatch( this, "dirwatch" );
@@ -226,7 +234,7 @@ bool KompareModelList::compareDirs( const QString& source, const QString& destin
 //	connect( m_dirWatch, SIGNAL( deleted( const QString& ) ), this, SLOT( slotDirectoryChanged( const QString& ) ) );
 
 //	m_dirWatch->startScan();
-	m_diffProcess = new KompareProcess( m_diffSettings, Kompare::Custom, m_source, m_destination );
+	m_diffProcess = new KompareProcess( m_diffSettings, Kompare::Custom, m_info->localSource, m_info->localDestination );
 	m_diffProcess->setEncoding( m_encoding );
 
 	connect( m_diffProcess, SIGNAL(diffHasFinished( bool )),
@@ -238,21 +246,20 @@ bool KompareModelList::compareDirs( const QString& source, const QString& destin
 	return true;
 }
 
-bool KompareModelList::openFileAndDiff( const QString& file, const QString& diff )
+bool KompareModelList::openFileAndDiff()
 {
 	clear();
 
-	if ( parseDiffOutput( readFile( diff ) ) != 0 )
+	if ( parseDiffOutput( readFile( m_info->localDestination ) ) != 0 )
 	{
-		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>", diff ) );
+		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>", m_info->destination.url() ) );
 		return false;
 	}
 
-	// Do our thing :)
-	if ( !blendOriginalIntoModelList( file ) )
+	if ( !blendOriginalIntoModelList( m_info->localSource ) )
 	{
-		kDebug(8101) << "Oops cant blend original file into modellist : " << file << endl;
-		emit( i18n( "<qt>There were problems applying the diff <b>%1</b> to the file <b>%2</b>.</qt>", diff, file ) );
+		kDebug(8101) << "Oops cant blend original file into modellist : " << m_info->localSource << endl;
+		emit( i18n( "<qt>There were problems applying the diff <b>%1</b> to the file <b>%2</b>.</qt>", m_info->destination.url(), m_info->source.url() ) );
 		return false;
 	}
 
@@ -262,22 +269,22 @@ bool KompareModelList::openFileAndDiff( const QString& file, const QString& diff
 	return true;
 }
 
-bool KompareModelList::openDirAndDiff( const QString& dir, const QString& diff )
+bool KompareModelList::openDirAndDiff()
 {
 	clear();
 
-	if ( parseDiffOutput( readFile( diff ) ) != 0 )
+	if ( parseDiffOutput( readFile( m_info->localDestination ) ) != 0 )
 	{
-		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>", diff ) );
+		emit error( i18n( "<qt>No models or no differences, this file: <b>%1</b>, is not a valid diff file.</qt>", m_info->destination.url() ) );
 		return false;
 	}
 
 	// Do our thing :)
-	if ( !blendOriginalIntoModelList( dir ) )
+	if ( !blendOriginalIntoModelList( m_info->localSource ) )
 	{
 		// Trouble blending the original into the model
-		kDebug(8101) << "Oops cant blend original dir into modellist : " << dir << endl;
-		emit error( i18n( "<qt>There were problems applying the diff <b>%1</b> to the folder <b>%2</b>.</qt>", diff, dir ) );
+		kDebug(8101) << "Oops cant blend original dir into modellist : " << m_info->localSource << endl;
+		emit error( i18n( "<qt>There were problems applying the diff <b>%1</b> to the folder <b>%2</b>.</qt>", m_info->destination.url(), m_info->source.url() ) );
 		return false;
 	}
 
@@ -302,17 +309,16 @@ bool KompareModelList::saveDestination( DiffModel* model )
 	if( !model->isModified() )
 		return true;
 
-	KTemporaryFile* temp = new KTemporaryFile();
-	temp->open();
+	KTemporaryFile temp;
+	temp.open();
 
-	if( temp->status() != 0 ) {
+	if( temp.status() != 0 ) {
 		emit error( i18n( "Could not open a temporary file." ) );
-		temp->remove();
-		delete temp;
+		temp.remove();
 		return false;
 	}
 
-	QTextStream stream( temp );
+	QTextStream stream( &temp );
 	QStringList list;
 
 	DiffHunkListConstIterator hunkIt = model->hunks()->begin();
@@ -355,51 +361,60 @@ bool KompareModelList::saveDestination( DiffModel* model )
 	if( list.count() > 0 )
 		stream << list.join( "" );
 
-	temp->close();
-	if( temp->status() != 0 ) {
-		emit error( i18n( "<qt>Could not write to the temporary file <b>%1</b>, deleting it.</qt>", temp->name() ) );
-		temp->remove();
-		delete temp;
+	temp.close();
+	if( temp.status() != 0 ) {
+		emit error( i18n( "<qt>Could not write to the temporary file <b>%1</b>, deleting it.</qt>", temp.name() ) );
+		temp.remove();
 		return false;
 	}
 
 	bool result = false;
 
-	if ( m_info.mode == Kompare::ComparingDirs )
+	// Make sure the destination directory exists, it is possible when using -N to not have the destination dir/file available
+	if ( m_info->mode == Kompare::ComparingDirs )
 	{
-		QString destination = model->destinationPath() + model->destinationFile();
-		kDebug(8101) << "Tempfilename   : " << temp->name() << endl;
-		kDebug(8101) << "DestinationURL : " << destination << endl;
+		// Dont use destination which was used for creating the diff directly, use the original URL!!!
+		// FIXME!!! Wrong destination this way! Need to add the sub directory to the url!!!!
+		kDebug(8101) << "Tempfilename (save) : " << temp.name() << endl;
+		kDebug(8101) << "Model->path+file    : " << model->destinationPath() << model->destinationFile() << endl;
+		kDebug(8101) << "info->localdest     : " << m_info->localDestination << endl;
+		QString tmp = model->destinationPath() + model->destinationFile();
+		if ( tmp.startsWith( m_info->localDestination ) ) // It should, if not serious trouble...
+			tmp.remove( 0, m_info->localDestination.size() );
+		kDebug(8101) << "DestinationURL      : " << m_info->destination << endl;
+		kDebug(8101) << "tmp                 : " << tmp << endl;
 		KIO::UDSEntry entry;
-		if ( !KIO::NetAccess::stat( KUrl( destination ).path(), entry, (QWidget*)parent() ) )
+		KUrl fullDestinationPath( m_info->destination );
+		fullDestinationPath.addPath( tmp );
+		kDebug(8101) << "fullDestinationPath : " << fullDestinationPath << endl;
+		if ( !KIO::NetAccess::stat( fullDestinationPath.directory(), entry, m_widgetForKIO ) )
 		{
-			if ( !KIO::NetAccess::mkdir( KUrl( destination ).path(), (QWidget*)parent() ) )
+			if ( !KIO::NetAccess::mkdir( fullDestinationPath.directory(), m_widgetForKIO ) )
 			{
-				emit error( i18n( "<qt>Could not create destination directory <b>%1</b>.\nThe file has not been saved.</qt>", destination ) );
+				emit error( i18n( "<qt>Could not create destination directory <b>%1</b>.\nThe file has not been saved.</qt>", fullDestinationPath.directory() ) );
 				return false;
 			}
 		}
-		result = KIO::NetAccess::upload( temp->name(), KUrl( destination ), (QWidget*)parent() );
+		result = KIO::NetAccess::upload( temp.name(), fullDestinationPath, m_widgetForKIO );
 	}
 	else
 	{
-		kDebug(8101) << "Tempfilename   : " << temp->name() << endl;
-		kDebug(8101) << "DestinationURL : " << m_destination << endl;
-		result = KIO::NetAccess::upload( temp->name(), KUrl( m_destination ), (QWidget*)parent() );
+		kDebug(8101) << "Tempfilename   : " << temp.name() << endl;
+		kDebug(8101) << "DestinationURL : " << m_info->destination << endl;
+		result = KIO::NetAccess::upload( temp.name(), m_info->destination, m_widgetForKIO );
+		kDebug(8101) << "true or false?" << result << endl;
 	}
 
 	if ( !result )
 	{
-		emit error( i18n( "<qt>Could not upload the temporary file to the destination location <b>%1</b>. The temporary file is still available under: <b>%2</b>. You can manually copy it to the right place.</qt>", m_destination, temp->name() ) );
+		emit error( i18n( "<qt>Could not upload the temporary file to the destination location <b>%1</b>. The temporary file is still available under: <b>%2</b>. You can manually copy it to the right place.</qt>", m_info->destination.url(), temp.name() ) );
                 //Don't remove file when we delete temp and don't leak it.
-                temp->setAutoRemove(false);
-                delete temp;
+                temp.setAutoRemove(false);
 	}
 	else
 	{
 		//model->slotSetModified( false );
-		temp->remove();
-		delete temp;
+		temp.remove();
 	}
 
 	return true;
@@ -449,10 +464,10 @@ void KompareModelList::slotDiffProcessFinished( bool success )
 		}
 		else
 		{
-			if ( m_info.mode != Kompare::ShowingDiff )
+			if ( m_info->mode != Kompare::ShowingDiff )
 			{
 				kDebug() << "Blend this crap please and do not give me any conflicts..." << endl;
-				blendOriginalIntoModelList( m_info.localSource );
+				blendOriginalIntoModelList( m_info->localSource );
 			}
 			updateModelListActions();
 			show();
@@ -468,7 +483,7 @@ void KompareModelList::slotDiffProcessFinished( bool success )
 		emit error( m_diffProcess->stdErr() );
 	}
 
-	delete m_diffProcess;
+	m_diffProcess->deleteLater();
 	m_diffProcess = 0;
 }
 
@@ -600,7 +615,7 @@ bool KompareModelList::saveDiff( const QString& url, QString directory, DiffSett
 		return false;
 	}
 
-	m_diffProcess = new KompareProcess( diffSettings, Kompare::Custom, m_source, m_destination, directory );
+	m_diffProcess = new KompareProcess( diffSettings, Kompare::Custom, m_info->localSource, m_info->localDestination, directory );
 	m_diffProcess->setEncoding( m_encoding );
 
 	connect( m_diffProcess, SIGNAL(diffHasFinished( bool )),
@@ -628,7 +643,7 @@ void KompareModelList::slotWriteDiffOutput( bool success )
 			emit error( i18n( "Could not write to the temporary file." ) );
 		}
 
-		KIO::NetAccess::upload( m_diffTemp->name(), KUrl( m_diffURL ), (QWidget*)parent() );
+		KIO::NetAccess::upload( m_diffTemp->name(), KUrl( m_diffURL ), m_widgetForKIO );
 
 		emit status( Kompare::FinishedWritingDiff );
 	}
@@ -758,7 +773,7 @@ DiffModel* KompareModelList::lastModel()
 DiffModel* KompareModelList::prevModel()
 {
 	kDebug( 8101 ) << "KompareModelList::prevModel()" << endl;
-	if ( --m_modelIndex < m_models->count() )
+	if ( m_modelIndex > 0 && --m_modelIndex < m_models->count() )
 	{
 		kDebug( 8101 ) << "m_modelIndex = " << m_modelIndex << endl;
 		m_selectedModel = (*m_models)[ m_modelIndex ];
@@ -882,8 +897,8 @@ int KompareModelList::parseDiffOutput( const QString& diff )
 	Parser* parser = new Parser( this );
 	m_models = parser->parse( diffLines );
 
-	m_info.generator = parser->generator();
-	m_info.format    = parser->format();
+	m_info->generator = parser->generator();
+	m_info->format    = parser->format();
 
 	delete parser;
 
@@ -1211,22 +1226,20 @@ void KompareModelList::clear()
 
 void KompareModelList::refresh()
 {
-	QString source = m_source;
-	QString destination = m_destination;
-	if ( m_info.mode == Kompare::ComparingFiles )
-		compareFiles( source, destination );
-	else if ( m_info.mode == Kompare::ComparingDirs )
-		compareDirs( source, destination );
+	// FIXME: I can imagine blending also wants to be refreshed so make a switch case here
+	if ( m_info->mode == Kompare::ComparingFiles )
+		compareFiles();
+	else if ( m_info->mode == Kompare::ComparingDirs )
+		compareDirs();
 }
 
 void KompareModelList::swap()
 {
-	QString source = m_source;
-	QString destination = m_destination;
-	if ( m_info.mode == Kompare::ComparingFiles )
-		compareFiles( destination, source );
-	else if ( m_info.mode == Kompare::ComparingDirs )
-		compareDirs( destination, source );
+	// Swap should not be active when there is a diff and a file/dir
+	if ( m_info->mode == Kompare::ComparingFiles )
+		compareFiles();
+	else if ( m_info->mode == Kompare::ComparingDirs )
+		compareDirs();
 }
 
 bool KompareModelList::isModified() const
@@ -1279,6 +1292,11 @@ void KompareModelList::slotSetModified( bool modified )
 	}
 }
 
+void KompareModelList::slotKompareInfo( struct Kompare::Info* info )
+{
+	m_info = info;
+}
+
 bool KompareModelList::setSelectedModel( DiffModel* model )
 {
 	kDebug(8101) << "KompareModelList::setSelectedModel( " << model << " )" << endl;
@@ -1302,6 +1320,7 @@ void KompareModelList::updateModelListActions()
 {
 	if ( m_models && m_selectedModel && m_selectedDifference )
 	{
+		// ARGH!!!! Casts are evil!!!
 		if ( ( ( KomparePart* )parent() )->isReadWrite() )
 		{
 			if ( m_selectedModel->appliedCount() != m_selectedModel->differenceCount() )
@@ -1314,8 +1333,8 @@ void KompareModelList::updateModelListActions()
 			else
 				m_unapplyAll->setEnabled( false );
 
-			m_applyDifference->setEnabled( true );
-			m_unApplyDifference->setEnabled( true );
+			m_applyDifference->setEnabled( m_selectedDifference->applied() == false );
+			m_unApplyDifference->setEnabled( m_selectedDifference->applied() == true );
 			m_save->setEnabled( m_selectedModel->isModified() );
 		}
 		else
