@@ -1,7 +1,7 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
-  Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
+  Copyright (C) 2007-2008 by Nick Shaforostoff <shafff@ukr.net>
 
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
@@ -44,9 +44,9 @@
 #include <kfiledialog.h>
 #include <kmessagebox.h>
 #include <ktextedit.h>
+#include <kaction.h>
 
 #include <QDragEnterEvent>
-#include <QAction>
 #include <QFile>
 
 MergeView::MergeView(QWidget* parent, Catalog* catalog,bool primary)
@@ -79,6 +79,13 @@ MergeView::~MergeView()
     delete m_mergeCatalog;
 }
 
+KUrl MergeView::url()
+{
+    if (m_mergeCatalog)
+        return m_mergeCatalog->url();
+    return KUrl();
+}
+
 void MergeView::dragEnterEvent(QDragEnterEvent* event)
 {
     if(event->mimeData()->hasUrls() && event->mimeData()->urls().first().path().endsWith(".po"))
@@ -154,11 +161,8 @@ void MergeView::slotNewEntryDisplayed(const DocPosition& pos)
             inTag=false;
     }
 #endif
-    //static QPalette::ColorRole roles[2]={/*QPalette::Base*/QPalette::LinkVisited,QPalette::AlternateBase};
-    //m_browser->viewport()->setBackgroundRole(roles[m_mergeCatalog->isFuzzy(pos.entry)]);
-//     static QPalette::ColorRole roles[2]={/*QPalette::Base*/QPalette::WindowText,QPalette::BrightText};
-    //m_browser->viewport()->setForegroundRole(roles[m_mergeCatalog->isFuzzy(pos.entry)]);
-    if (m_mergeCatalog->isFuzzy(pos.entry))
+
+    if (!m_mergeCatalog->isApproved(pos.entry))
     {
         result.prepend("<i>");
         result.append("</i>");
@@ -235,7 +239,6 @@ void MergeView::mergeOpen(KUrl url)
 
 }
 
-
 int MergeView::pluralFormsAvailableForward()
 {
     if(KDE_ISLIKELY( m_pos.entry==-1 || !m_mergeCatalog->isPlural(m_pos.entry) ))
@@ -313,31 +316,36 @@ void MergeView::mergeAccept()
 {
     if(m_pos.entry==-1
        ||!m_mergeCatalog
-       ||m_baseCatalog->msgstr(m_pos)==m_mergeCatalog->msgstr(m_pos)
+     //||m_baseCatalog->msgstr(m_pos)==m_mergeCatalog->msgstr(m_pos)
        ||m_mergeCatalog->msgstr(m_pos).isEmpty())
         return;
+    bool changeContents=m_baseCatalog->msgstr(m_pos)!=m_mergeCatalog->msgstr(m_pos);
 
     m_baseCatalog->beginMacro(i18nc("@item Undo action item","Accept change in translation"));
 
-    m_pos.offset=0;
-    if (!m_baseCatalog->msgstr(m_pos).isEmpty())
-        m_baseCatalog->push(new DelTextCmd(m_baseCatalog,m_pos,m_baseCatalog->msgstr(m_pos)));
-
-    if ( m_baseCatalog->isFuzzy(m_pos.entry) && !m_mergeCatalog->isFuzzy(m_pos.entry)       )
+    if ( !m_baseCatalog->isApproved(m_pos.entry) && m_mergeCatalog->isApproved(m_pos.entry)       )
         m_baseCatalog->push(new ToggleFuzzyCmd(m_baseCatalog,m_pos.entry,false));
-    else if ( !m_baseCatalog->isFuzzy(m_pos.entry) && m_mergeCatalog->isFuzzy(m_pos.entry) )
+    else if ( m_baseCatalog->isApproved(m_pos.entry) && !m_mergeCatalog->isApproved(m_pos.entry) )
         m_baseCatalog->push(new ToggleFuzzyCmd(m_baseCatalog,m_pos.entry,true));
 
-    m_baseCatalog->push(new InsTextCmd(m_baseCatalog,m_pos,m_mergeCatalog->msgstr(m_pos)));
+    if (changeContents)
+    {
+        m_pos.offset=0;
+        if (!m_baseCatalog->msgstr(m_pos).isEmpty())
+            m_baseCatalog->push(new DelTextCmd(m_baseCatalog,m_pos,m_baseCatalog->msgstr(m_pos)));
+
+        m_baseCatalog->push(new InsTextCmd(m_baseCatalog,m_pos,m_mergeCatalog->msgstr(m_pos)));
+    }
     ////////this is NOT done automatically by BaseCatalogEntryChanged slot
     bool remove=true;
     if (m_mergeCatalog->isPlural(m_pos.entry))
     {
         DocPosition pos=m_pos;
-        pos.form=qMax(m_baseCatalog->numberOfPluralForms(),1);
+        pos.form=qMin(m_baseCatalog->numberOfPluralForms(),m_mergeCatalog->numberOfPluralForms());//just sanity check
+        pos.form=qMax((int)pos.form,1);//just sanity check
         while ((--(pos.form))>=0)
         {
-            kWarning()<<pos.form;
+            //kWarning()<<pos.form;
             if (m_baseCatalog->msgstr(pos)!=m_mergeCatalog->msgstr(pos))
             {
                 remove=false;
@@ -417,3 +425,5 @@ void MergeView::mergeAcceptAllForEmpty()
 }
 
 
+
+#include "mergeview.moc"
