@@ -1,5 +1,5 @@
 /* ****************************************************************************
-  This file is part of KAider
+  This file is part of Lokalize
 
   Copyright (C) 2007 by Nick Shaforostoff <shafff@ukr.net>
 
@@ -83,7 +83,7 @@ class ProjectModel: public KDirModel
     Q_OBJECT
 
 public:
-    ProjectModel();
+    ProjectModel(QObject *parent);
     ~ProjectModel(){}
 
     QVariant data (const QModelIndex&, int role=Qt::DisplayRole) const;
@@ -95,7 +95,8 @@ public:
     void openUrl(const KUrl&);
 
 public slots:
-    void aa(){kWarning()<<"dataChanged";}
+    //void aa(){kWarning()<<"dataChanged";}
+    //void readRecursively(const QModelIndex& parent=QModelIndex());
 
 private:
     KIcon m_dirIcon;
@@ -133,7 +134,7 @@ public:
 
 public:
     /**
-     * made in assuption that KDirModel doesnt rely on completed() signal!
+     * made in assuption that KDirModel does not rely on completed() signal!
      * otherwise, would probably use qtimer::singleshot()
      */
     bool openUrl(const KUrl&, OpenUrlFlags flags = NoFlags);
@@ -175,7 +176,7 @@ private:
     //HACKs
     bool m_reactOnSignals;
     QHash<QString /*url.path()*/,bool> m_listedTemplDirs;
-    ProjectModel* m_model;//used for debuging
+    ProjectModel* m_model;//used for debugging
 };
 
 
