@@ -38,7 +38,7 @@ public:
      * @param view              The parent to this widget.
      * @param id                The ID to assign (-1 will prompt a new ID.)
      */
-    BoxWidget(UMLView * view, Uml::IDType id = Uml::id_None);
+    explicit BoxWidget(UMLView * view, Uml::IDType id = Uml::id_None);
 
     /**
      * destructor
@@ -51,7 +51,7 @@ public:
     void draw(QPainter & p, int offsetX, int offsetY);
 
     /**
-     * Saves the widget to the <boxwidget> XMI element.
+     * Saves the widget to the "boxwidget" XMI element.
      * Note: For loading from XMI, the inherited parent method is used.
      */
     void saveToXMI(QDomDocument& qDoc, QDomElement& qElement);
