@@ -1,5 +1,4 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
@@ -12,21 +11,25 @@
 // own header
 #include "adaimport.h"
 
-#include <stdio.h>
-// qt/kde includes
-#include <QtCore/QRegExp>
-#include <kdebug.h>
 // app includes
+#include "association.h"
+#include "attribute.h"
+#include "classifier.h"
+#include "enum.h"
+#include "folder.h"
 #include "import_utils.h"
-#include "../uml.h"
-#include "../umldoc.h"
-#include "../package.h"
-#include "../folder.h"
-#include "../classifier.h"
-#include "../enum.h"
-#include "../operation.h"
-#include "../attribute.h"
-#include "../association.h"
+#include "operation.h"
+#include "package.h"
+#include "uml.h"
+#include "umldoc.h"
+
+// kde includes
+#include <kdebug.h>
+
+// qt includes
+#include <QtCore/QRegExp>
+
+#include <stdio.h>
 
 AdaImport::AdaImport() : NativeImportBase("--")
 {
@@ -54,7 +57,7 @@ QStringList AdaImport::split(const QString& lin)
     bool seenSpace = false;
     QString line = lin.trimmed();
     uint len = line.length();
-    for (uint i = 0; i < len; i++) {
+    for (uint i = 0; i < len; ++i) {
         const QChar& c = line[i];
         if (inString) {
             listElement += c;
@@ -64,7 +67,7 @@ QStringList AdaImport::split(const QString& lin)
                     continue;
                 }
                 list.append(listElement);
-                listElement = QString();
+                listElement.clear();
                 inString = false;
             }
         } else if (c == '"') {
@@ -108,7 +111,7 @@ void AdaImport::fillSource(const QString& word)
 {
     QString lexeme;
     const uint len = word.length();
-    for (uint i = 0; i < len; i++) {
+    for (uint i = 0; i < len; ++i) {
         QChar c = word[i];
         if (c.isLetterOrNumber() || c == '_' || c == '.' || c == '#') {
             lexeme += c;
@@ -184,7 +187,7 @@ bool AdaImport::parseStmt()
             return false;
         }
         while (++m_srcIndex < srcLength && m_source[m_srcIndex] != ";") {
-            QStringList components = m_source[m_srcIndex].toLower().split(".");
+            QStringList components = m_source[m_srcIndex].toLower().split('.');
             const QString& prefix = components.first();
             if (prefix == "system" || prefix == "ada" || prefix == "gnat" ||
                 prefix == "interfaces" || prefix == "text_io" ||
@@ -206,7 +209,7 @@ bool AdaImport::parseStmt()
     }
     if (keyword == "package") {
         const QString& name = advance();
-        QStringList parentPkgs = name.toLower().split(".");
+        QStringList parentPkgs = name.toLower().split('.');
         parentPkgs.pop_back();  // exclude the current package
         parseStems(parentPkgs);
         UMLObject *ns = NULL;
@@ -297,7 +300,7 @@ bool AdaImport::parseStmt()
             UMLEnum *enumType = static_cast<UMLEnum*>(ns);
             while ((next = advance()) != ")") {
                 Import_Utils::addEnumLiteral(enumType, next, m_comment);
-                m_comment = QString();
+                m_comment.clear();
                 if (advance() != ",")
                     break;
             }
@@ -495,11 +498,12 @@ bool AdaImport::parseStmt()
                 // The controlling parameter is suppressed.
                 parNameCount--;
                 if (parNameCount) {
-                    for (uint i = 0; i < parNameCount; i++)
+                    for (uint i = 0; i < parNameCount; ++i) {
                         parName[i] = parName[i + 1];
+                    }
                 }
             }
-            for (uint i = 0; i < parNameCount; i++) {
+            for (uint i = 0; i < parNameCount; ++i) {
                 UMLAttribute *att = Import_Utils::addMethodParameter(op, typeName, parName[i]);
                 att->setParmKind(dir);
             }
