@@ -5,7 +5,7 @@
  *   the Free Software Foundation; either version 2 of the License, or     *
  *   (at your option) any later version.                                   *
  *                                                                         *
- *   copyright (C) 2003-2007                                               *
+ *   copyright (C) 2003-2008                                               *
  *   Umbrello UML Modeller Authors <uml-devel@uml.sf.net>                  *
  ***************************************************************************/
 
@@ -21,6 +21,7 @@
 #include "uml.h"
 #include "umldoc.h"
 #include "umlview.h"
+#include <QPolygon>
 
 NodeWidget::NodeWidget(UMLView * view, UMLNode *n )
   : UMLWidget(view, n) {
@@ -34,11 +35,11 @@ NodeWidget::NodeWidget(UMLView * view, UMLNode *n )
 NodeWidget::~NodeWidget() {}
 
 void NodeWidget::draw(QPainter & p, int offsetX, int offsetY) {
-    UMLWidget::setPen(p);
+    setPenFromSettings(p);
     if ( UMLWidget::getUseFillColour() ) {
         p.setBrush( UMLWidget::getFillColour() );
     } else {
-        p.setBrush( m_pView->viewport()->backgroundColor() );
+        p.setBrush( m_pView->viewport()->palette().color(QPalette::Background) );
     }
     const int w = width();
     const int h = height();
@@ -53,7 +54,7 @@ void NodeWidget::draw(QPainter & p, int offsetX, int offsetY) {
     const int fontHeight  = fm.lineSpacing();
     QString name = getName();
 
-    QPointArray pointArray(5);
+    QPolygon pointArray(5);
     pointArray.setPoint(0, offsetX, bodyOffsetY);
     pointArray.setPoint(1, offsetX + wDepth, offsetY);
     pointArray.setPoint(2, offsetX + w - 1, offsetY);
@@ -97,7 +98,7 @@ void NodeWidget::draw(QPainter & p, int offsetX, int offsetY) {
 
 QSize NodeWidget::calculateSize() {
     if (m_pObject == NULL) {
-        kDebug() << "NodeWidget::calculateSize: m_pObject is NULL" << endl;
+        uDebug() << "m_pObject is NULL";
         return UMLWidget::calculateSize();
     }
 
