@@ -1,5 +1,4 @@
 /***************************************************************************
- *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
  *   the Free Software Foundation; either version 2 of the License, or     *
@@ -12,18 +11,44 @@
 // own header
 #include "uml.h"
 
-// qt includes
-#include <QtCore/QTimer>
-#include <QtCore/QRegExp>
-#include <QtGui/QClipboard>
-#include <QtGui/QSlider>
-#include <QtGui/QToolButton>
-#include <QtGui/QKeyEvent>
-#include <QtGui/QMenuItem>
-#include <QtGui/QDockWidget>
-#include <QtGui/QStackedWidget>
-#include <QtGui/QPrinter>
-#include <QtGui/QPrintDialog>
+// app includes
+#include "umldoc.h"
+#include "umllistview.h"
+#include "umlviewlist.h"
+#include "worktoolbar.h"
+#include "umlviewimageexporter.h"
+#include "umlviewimageexporterall.h"
+#include "kplayerslideraction.h"
+#include "docwindow.h"
+#include "optionstate.h"
+#include "cmdlineexportallviewsevent.h"
+#include "cmds.h"
+#include "umbrellosettings.h"
+// code generation
+#include "codegenerator.h"
+#include "codegenerationpolicy.h"
+#include "codegenfactory.h"
+#include "codegenpolicyext.h"
+#include "simplecodegenerator.h"
+// utils
+#include "widget_utils.h"
+#include "icon_utils.h"
+#include "model_utils.h"
+// dialogs
+#include "classwizard.h"
+#include "codegenerationwizard.h"
+#include "codeviewerdialog.h"
+#include "diagramprintpage.h"
+#include "importprojectdlg.h"
+#include "settingsdlg.h"
+#include "classimport.h"
+#include "refactoring/refactoringassistant.h"
+// clipboard
+#include "clipboard/umlclipboard.h"
+#include "clipboard/umldragdata.h"
+// docgenerators
+#include "docgenerators/docbookgenerator.h"
+#include "docgenerators/xhtmlgenerator.h"
 
 // kde includes
 #include <kaction.h>
@@ -51,47 +76,22 @@
 #include <kxmlguifactory.h>
 #include <kapplication.h>
 #include <kdeprintdialog.h>
+#include <kundostack.h>
 
-// app includes
-#include "umldoc.h"
-#include "umllistview.h"
-#include "umlviewlist.h"
-#include "worktoolbar.h"
-#include "umlviewimageexporter.h"
-#include "umlviewimageexporterall.h"
-#include "kplayerslideraction.h"
-#include "docwindow.h"
-#include "optionstate.h"
-#include "configurable.h"
-#include "cmdlineexportallviewsevent.h"
-#include "cmds.h"
-#include "umbrellosettings.h"
-// code generation
-#include "codegenerator.h"
-#include "codegenerationpolicy.h"
-#include "codegenerators/codegenfactory.h"
-#include "codegenerators/codegenpolicyext.h"
-#include "codegenerators/simplecodegenerator.h"
-// utils
-#include "widget_utils.h"
-#include "icon_utils.h"
-#include "model_utils.h"
-// dialogs
-#include "classwizard.h"
-#include "codegenwizard/codegenerationwizard.h"
-#include "codeviewerdialog.h"
-#include "diagramprintpage.h"
-#include "importprojectdlg.h"
-#include "settingsdlg.h"
-#include "codeimport/classimport.h"
-#include "refactoring/refactoringassistant.h"
-// clipboard
-#include "clipboard/umlclipboard.h"
-#include "clipboard/umldragdata.h"
-// docgenerators
-#include "docgenerators/docbookgenerator.h"
-#include "docgenerators/xhtmlgenerator.h"
-
+// qt includes
+#include <QtCore/QTimer>
+#include <QtCore/QRegExp>
+#include <QtGui/QClipboard>
+#include <QtGui/QSlider>
+#include <QtGui/QToolButton>
+#include <QtGui/QKeyEvent>
+#include <QtGui/QMenu>
+#include <QtGui/QMenuItem>
+#include <QtGui/QDockWidget>
+#include <QtGui/QStackedWidget>
+#include <QtGui/QPrinter>
+#include <QtGui/QPrintDialog>
+#include <QtGui/QUndoView>
 
 // Static pointer, holding the last created instance.
 UMLApp* UMLApp::s_instance;
@@ -134,7 +134,9 @@ UMLApp::UMLApp(QWidget* parent) : KXmlGuiWindow(parent)
     // call this here because the statusBar is shown/hidden by setupGUI()
     initStatusBar();
     // use the absolute path to your umbrelloui.rc file for testing purpose in setupGUI();
-    setupGUI();
+    StandardWindowOptions opt = Default;
+    opt &= ~Save;
+    setupGUI( opt );
     initView();
     initClip();
     readOptions();
@@ -163,6 +165,9 @@ UMLApp::UMLApp(QWidget* parent) : KXmlGuiWindow(parent)
     m_refactoringAssist   = NULL;
     m_commoncodegenpolicy = new CodeGenerationPolicy();
     m_imageExporterAll    = new UMLViewImageExporterAll();
+
+    setAutoSaveSettings();
+    toolsbar->setToolButtonStyle(Qt::ToolButtonIconOnly); //too many items for text, really we want a toolbox widget
 }
 
 UMLApp::~UMLApp()
@@ -184,20 +189,18 @@ void UMLApp::setProgLangAction(Uml::Programming_Language pl, const QString& name
     m_langAct[pl] = actionCollection()->addAction(action);
     m_langAct[pl]->setText(name);
     m_langAct[pl]->setCheckable(true);
-    const char* method = QString('1' + action + "()").toAscii().constData();
-    connect(m_langAct[pl], SIGNAL(triggered()), this, method);
 }
 
 void UMLApp::initActions()
 {
-    fileNew = KStandardAction::openNew(this, SLOT(slotFileNew()), actionCollection());
-    fileOpen = KStandardAction::open(this, SLOT(slotFileOpen()), actionCollection());
+    QAction* fileNew = KStandardAction::openNew(this, SLOT(slotFileNew()), actionCollection());
+    QAction* fileOpen = KStandardAction::open(this, SLOT(slotFileOpen()), actionCollection());
     fileOpenRecent = KStandardAction::openRecent(this, SLOT(slotFileOpenRecent(const KUrl&)), actionCollection());
-    fileSave = KStandardAction::save(this, SLOT(slotFileSave()), actionCollection());
-    fileSaveAs = KStandardAction::saveAs(this, SLOT(slotFileSaveAs()), actionCollection());
-    fileClose = KStandardAction::close(this, SLOT(slotFileClose()), actionCollection());
+    QAction* fileSave = KStandardAction::save(this, SLOT(slotFileSave()), actionCollection());
+    QAction* fileSaveAs = KStandardAction::saveAs(this, SLOT(slotFileSaveAs()), actionCollection());
+    QAction* fileClose = KStandardAction::close(this, SLOT(slotFileClose()), actionCollection());
     filePrint = KStandardAction::print(this, SLOT(slotFilePrint()), actionCollection());
-    fileQuit = KStandardAction::quit(this, SLOT(slotFileQuit()), actionCollection());
+    QAction* fileQuit = KStandardAction::quit(this, SLOT(slotFileQuit()), actionCollection());
 
     editUndo = m_pUndoStack->createUndoAction(actionCollection());
     editRedo = m_pUndoStack->createRedoAction(actionCollection());
@@ -208,43 +211,45 @@ void UMLApp::initActions()
     editCut = KStandardAction::cut(this, SLOT(slotEditCut()), actionCollection());
     editCopy = KStandardAction::copy(this, SLOT(slotEditCopy()), actionCollection());
     editPaste = KStandardAction::paste(this, SLOT(slotEditPaste()), actionCollection());
+
     createStandardStatusBarAction();
     setStandardToolBarMenuEnabled(true);
-    selectAll = KStandardAction::selectAll(this,  SLOT( slotSelectAll() ), actionCollection());
 
-    fileExportDocbook = actionCollection()->addAction("file_export_docbook");
+    /* QAction* selectAll = */ KStandardAction::selectAll(this,  SLOT( slotSelectAll() ), actionCollection());
+
+    QAction* fileExportDocbook = actionCollection()->addAction("file_export_docbook");
     fileExportDocbook->setText(i18n("&Export model to DocBook"));
     connect(fileExportDocbook, SIGNAL( triggered( bool ) ), this, SLOT( slotFileExportDocbook() ));
 
-    fileExportXhtml = actionCollection()->addAction("file_export_xhtml");
+    QAction* fileExportXhtml = actionCollection()->addAction("file_export_xhtml");
     fileExportXhtml->setText(i18n("&Export model to XHTML"));
     connect(fileExportXhtml, SIGNAL( triggered( bool ) ), this, SLOT( slotFileExportXhtml() ));
 
-    classWizard = actionCollection()->addAction("class_wizard");
+    QAction* classWizard = actionCollection()->addAction("class_wizard");
     classWizard->setText(i18n("&New Class Wizard..."));
     connect(classWizard, SIGNAL( triggered( bool ) ), this, SLOT( slotClassWizard() ));
 
-    QAction* anAction = actionCollection()->addAction("create_default_datatypes");
-    anAction->setText(i18n("&Add Default Datatypes for Active Language"));
-    connect(anAction, SIGNAL( triggered( bool ) ), this, SLOT( slotAddDefaultDatatypes() ));
+    QAction* addDefDatatypes = actionCollection()->addAction("create_default_datatypes");
+    addDefDatatypes->setText(i18n("&Add Default Datatypes for Active Language"));
+    connect(addDefDatatypes, SIGNAL( triggered( bool ) ), this, SLOT( slotAddDefaultDatatypes() ));
 
-    preferences = KStandardAction::preferences(this,  SLOT( slotPrefs() ), actionCollection());
+    QAction* preferences = KStandardAction::preferences(this,  SLOT( slotPrefs() ), actionCollection());
 
-    importClasses = actionCollection()->addAction("import_class");
+    QAction* importClasses = actionCollection()->addAction("import_class");
     importClasses->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Import_Class));
     importClasses->setText(i18n("&Import Classes..."));
     connect(importClasses, SIGNAL( triggered( bool ) ), this, SLOT( slotImportClasses() ));
 
-    importProject = actionCollection()->addAction("import_project");
+    QAction* importProject = actionCollection()->addAction("import_project");
     importProject->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Import_Project));
     importProject->setText(i18n("Import &Project..."));
     connect(importProject, SIGNAL( triggered( bool ) ), this, SLOT( slotImportProject() ));
 
-    genWizard = actionCollection()->addAction("generation_wizard");
+    QAction* genWizard = actionCollection()->addAction("generation_wizard");
     genWizard->setText(i18n("&Code Generation Wizard..."));
     connect(genWizard, SIGNAL( triggered( bool ) ), this, SLOT( generationWizard() ));
 
-    genAll = actionCollection()->addAction("generate_all");
+    QAction* genAll = actionCollection()->addAction("generate_all");
     genAll->setText(i18n("&Generate All Code"));
     connect(genAll, SIGNAL( triggered( bool ) ), this, SLOT( generateAllCode() ));
 
@@ -267,7 +272,26 @@ void UMLApp::initActions()
     setProgLangAction(Uml::pl_SQL,          "SQL",             "setLang_sql");
     setProgLangAction(Uml::pl_Tcl,          "Tcl",             "setLang_tcl");
     setProgLangAction(Uml::pl_XMLSchema,    "XMLSchema",       "setLang_xmlschema");
-    setProgLangAction(Uml::pl_Ocl,          "Ocl",             "setLang_ocl");
+
+    connect(m_langAct[Uml::pl_ActionScript], SIGNAL(triggered()), this, SLOT(setLang_actionscript()));
+    connect(m_langAct[Uml::pl_Ada],          SIGNAL(triggered()), this, SLOT(setLang_ada()));
+    connect(m_langAct[Uml::pl_Cpp],          SIGNAL(triggered()), this, SLOT(setLang_cpp()));
+    connect(m_langAct[Uml::pl_CSharp],       SIGNAL(triggered()), this, SLOT(setLang_csharp()));
+    connect(m_langAct[Uml::pl_D],            SIGNAL(triggered()), this, SLOT(setLang_d()));
+    connect(m_langAct[Uml::pl_IDL],          SIGNAL(triggered()), this, SLOT(setLang_idl()));
+    connect(m_langAct[Uml::pl_Java],         SIGNAL(triggered()), this, SLOT(setLang_java()));
+    connect(m_langAct[Uml::pl_JavaScript],   SIGNAL(triggered()), this, SLOT(setLang_javascript()));
+    connect(m_langAct[Uml::pl_MySQL],        SIGNAL(triggered()), this, SLOT(setLang_mysql()));
+    connect(m_langAct[Uml::pl_Pascal],       SIGNAL(triggered()), this, SLOT(setLang_pascal()));
+    connect(m_langAct[Uml::pl_Perl],         SIGNAL(triggered()), this, SLOT(setLang_perl()));
+    connect(m_langAct[Uml::pl_PHP],          SIGNAL(triggered()), this, SLOT(setLang_php()));
+    connect(m_langAct[Uml::pl_PHP5],         SIGNAL(triggered()), this, SLOT(setLang_php5()));
+    connect(m_langAct[Uml::pl_PostgreSQL],   SIGNAL(triggered()), this, SLOT(setLang_postgresql()));
+    connect(m_langAct[Uml::pl_Python],       SIGNAL(triggered()), this, SLOT(setLang_python()));
+    connect(m_langAct[Uml::pl_Ruby],         SIGNAL(triggered()), this, SLOT(setLang_ruby()));
+    connect(m_langAct[Uml::pl_SQL],          SIGNAL(triggered()), this, SLOT(setLang_sql()));
+    connect(m_langAct[Uml::pl_Tcl],          SIGNAL(triggered()), this, SLOT(setLang_tcl()));
+    connect(m_langAct[Uml::pl_XMLSchema],    SIGNAL(triggered()), this, SLOT(setLang_xmlschema()));
 
     fileNew->setToolTip(i18n("Creates a new document"));
     fileOpen->setToolTip(i18n("Opens an existing document"));
@@ -295,55 +319,55 @@ void UMLApp::initActions()
     newDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_New) );
     newDiagram->setText( "new_view" );
 
-    classDiagram = actionCollection()->addAction( "new_class_diagram" );
+    QAction* classDiagram = actionCollection()->addAction( "new_class_diagram" );
     classDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Class) );
     classDiagram->setText( i18n( "&Class Diagram..." ) );
     connect(classDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotClassDiagram() ));
     newDiagram->addAction(classDiagram);
 
-    sequenceDiagram= actionCollection()->addAction( "new_sequence_diagram" );
+    QAction* sequenceDiagram= actionCollection()->addAction( "new_sequence_diagram" );
     sequenceDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Sequence) );
     sequenceDiagram->setText( i18n( "&Sequence Diagram..." ) );
     connect(sequenceDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotSequenceDiagram() ));
     newDiagram->addAction(sequenceDiagram);
 
-    collaborationDiagram = actionCollection()->addAction( "new_collaboration_diagram" );
+    QAction* collaborationDiagram = actionCollection()->addAction( "new_collaboration_diagram" );
     collaborationDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Collaboration) );
     collaborationDiagram->setText( i18n( "C&ollaboration Diagram..." ) );
     connect(collaborationDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotCollaborationDiagram() ));
     newDiagram->addAction(collaborationDiagram);
 
-    useCaseDiagram= actionCollection()->addAction( "new_use_case_diagram" );
+    QAction* useCaseDiagram = actionCollection()->addAction( "new_use_case_diagram" );
     useCaseDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Usecase) );
     useCaseDiagram->setText( i18n( "&Use Case Diagram..." ) );
     connect(useCaseDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotUseCaseDiagram() ));
     newDiagram->addAction(useCaseDiagram);
 
-    stateDiagram= actionCollection()->addAction( "new_state_diagram" );
+    QAction* stateDiagram = actionCollection()->addAction( "new_state_diagram" );
     stateDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_State) );
     stateDiagram->setText( i18n( "S&tate Diagram..." ) );
     connect(stateDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotStateDiagram() ));
     newDiagram->addAction(stateDiagram);
 
-    activityDiagram= actionCollection()->addAction( "new_activity_diagram" );
+    QAction* activityDiagram = actionCollection()->addAction( "new_activity_diagram" );
     activityDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Activity) );
     activityDiagram->setText( i18n( "&Activity Diagram..." ) );
     connect(activityDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotActivityDiagram() ));
     newDiagram->addAction(activityDiagram);
 
-    componentDiagram = actionCollection()->addAction( "new_component_diagram" );
+    QAction* componentDiagram = actionCollection()->addAction( "new_component_diagram" );
     componentDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Component) );
     componentDiagram->setText( i18n("Co&mponent Diagram...") );
     connect(componentDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotComponentDiagram() ));
     newDiagram->addAction(componentDiagram);
 
-    deploymentDiagram = actionCollection()->addAction( "new_deployment_diagram" );
+    QAction* deploymentDiagram = actionCollection()->addAction( "new_deployment_diagram" );
     deploymentDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_Deployment) );
     deploymentDiagram->setText( i18n("&Deployment Diagram...") );
     connect(deploymentDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotDeploymentDiagram() ));
     newDiagram->addAction(deploymentDiagram);
 
-    entityRelationshipDiagram = actionCollection()->addAction( "new_entityrelationship_diagram" );
+    QAction* entityRelationshipDiagram = actionCollection()->addAction( "new_entityrelationship_diagram" );
     entityRelationshipDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Diagram_EntityRelationship) );
     entityRelationshipDiagram->setText( i18n("&Entity Relationship Diagram...") );
     connect(entityRelationshipDiagram, SIGNAL( triggered( bool ) ), this, SLOT( slotEntityRelationshipDiagram() ));
@@ -362,6 +386,7 @@ void UMLApp::initActions()
     viewShowGrid->setText(i18n("S&how Grid"));
     connect(viewShowGrid, SIGNAL( triggered( bool ) ), this, SLOT( slotCurrentViewToggleShowGrid() ));
     viewShowGrid->setCheckedState(KGuiItem(i18n("&Hide Grid")));
+
     deleteDiagram = actionCollection()->addAction( "view_delete" );
     deleteDiagram->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Delete) );
     deleteDiagram->setText( i18n("&Delete") );
@@ -372,7 +397,7 @@ void UMLApp::initActions()
     viewExportImage->setText( i18n("&Export as Picture...") );
     connect(viewExportImage, SIGNAL( triggered( bool ) ), this, SLOT( slotCurrentViewExportImage() ));
 
-    viewExportImageAll = actionCollection()->addAction( "view_export_image_all" );
+    QAction* viewExportImageAll = actionCollection()->addAction( "view_export_image_all" );
     viewExportImageAll->setIcon( Icon_Utils::SmallIcon(Icon_Utils::it_Export_Picture) );
     viewExportImageAll->setText( i18n("Export &All Diagrams as Pictures...") );
     connect(viewExportImageAll, SIGNAL( triggered( bool ) ), this, SLOT( slotAllViewsExportImage() ));
@@ -402,56 +427,56 @@ void UMLApp::initActions()
     zoom100Action->setText(i18n("Z&oom to 100%"));
     connect(zoom100Action, SIGNAL( triggered( bool ) ), this, SLOT( slotZoom100() ));
 
-    alignRight = actionCollection()->addAction( "align_right" );
+    QAction* alignRight = actionCollection()->addAction( "align_right" );
     alignRight->setText(i18n("Align Right" ));
     alignRight->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_Right) );
     connect(alignRight, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignRight() ));
 
-    alignLeft = actionCollection()->addAction( "align_left" );
+    QAction* alignLeft = actionCollection()->addAction( "align_left" );
     alignLeft->setText(i18n("Align Left" ));
     alignLeft->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_Left) );
     connect(alignLeft, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignLeft() ));
 
-    alignTop = actionCollection()->addAction( "align_top" );
+    QAction* alignTop = actionCollection()->addAction( "align_top" );
     alignTop->setText(i18n("Align Top" ));
     alignTop->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_Top) );
     connect(alignTop, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignTop() ));
 
-    alignBottom = actionCollection()->addAction( "align_bottom" );
+    QAction* alignBottom = actionCollection()->addAction( "align_bottom" );
     alignBottom->setText(i18n("Align Bottom" ));
     alignBottom->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_Bottom) );
     connect(alignBottom, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignBottom() ));
 
-    alignVerticalMiddle = actionCollection()->addAction( "align_vertical_middle" );
+    QAction* alignVerticalMiddle = actionCollection()->addAction( "align_vertical_middle" );
     alignVerticalMiddle->setText(i18n("Align Vertical Middle" ));
     alignVerticalMiddle->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_VerticalMiddle) );
     connect(alignVerticalMiddle, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignVerticalMiddle() ));
 
-    alignHorizontalMiddle = actionCollection()->addAction( "align_horizontal_middle" );
+    QAction* alignHorizontalMiddle = actionCollection()->addAction( "align_horizontal_middle" );
     alignHorizontalMiddle->setText(i18n("Align Horizontal Middle" ));
     alignHorizontalMiddle->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_HorizontalMiddle) );
     connect(alignHorizontalMiddle, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignHorizontalMiddle() ));
 
-    alignVerticalDistribute = actionCollection()->addAction( "align_vertical_distribute" );
+    QAction* alignVerticalDistribute = actionCollection()->addAction( "align_vertical_distribute" );
     alignVerticalDistribute->setText(i18n("Align Vertical Distribute" ));
     alignVerticalDistribute->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_VerticalDistribute) );
     connect(alignVerticalDistribute, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignVerticalDistribute() ));
 
-    alignHorizontalDistribute = actionCollection()->addAction( "align_horizontal_distribute" );
+    QAction* alignHorizontalDistribute = actionCollection()->addAction( "align_horizontal_distribute" );
     alignHorizontalDistribute->setText(i18n("Align Horizontal Distribute" ));
     alignHorizontalDistribute->setIcon(Icon_Utils::SmallIcon(Icon_Utils::it_Align_HorizontalDistribute) );
     connect(alignHorizontalDistribute, SIGNAL( triggered( bool ) ), this, SLOT( slotAlignHorizontalDistribute() ));
 
     QString moveTabLeftString = i18n("&Move Tab Left");
     QString moveTabRightString = i18n("&Move Tab Right");
-    moveTabLeft = actionCollection()->addAction("move_tab_left");
+    KAction* moveTabLeft = actionCollection()->addAction("move_tab_left");
     moveTabLeft->setIcon(Icon_Utils::SmallIcon(QApplication::layoutDirection() ? Icon_Utils::it_Go_Next : Icon_Utils::it_Go_Previous));
     moveTabLeft->setText(QApplication::layoutDirection() ? moveTabRightString : moveTabLeftString);
     moveTabLeft->setShortcut(QApplication::layoutDirection() ?
                  QKeySequence(Qt::CTRL+Qt::SHIFT+Qt::Key_Right) : QKeySequence(Qt::CTRL+Qt::SHIFT+Qt::Key_Left));
     connect(moveTabLeft, SIGNAL( triggered( bool ) ), this, SLOT( slotMoveTabLeft() ));
 
-    moveTabRight = actionCollection()->addAction("move_tab_right");
+    KAction* moveTabRight = actionCollection()->addAction("move_tab_right");
     moveTabRight->setIcon(Icon_Utils::SmallIcon(QApplication::layoutDirection() ? Icon_Utils::it_Go_Previous : Icon_Utils::it_Go_Next));
     moveTabRight->setText(QApplication::layoutDirection() ? moveTabLeftString : moveTabRightString);
     moveTabRight->setShortcut(QApplication::layoutDirection() ?
@@ -460,13 +485,13 @@ void UMLApp::initActions()
 
     QString selectTabLeftString = i18n("Select Diagram on Left");
     QString selectTabRightString = i18n("Select Diagram on Right");
-    changeTabLeft = actionCollection()->addAction("previous_tab");
+    KAction* changeTabLeft = actionCollection()->addAction("previous_tab");
     changeTabLeft->setText(QApplication::layoutDirection() ? selectTabRightString : selectTabLeftString);
     changeTabLeft->setShortcut(QApplication::layoutDirection() ?
                    QKeySequence(Qt::SHIFT+Qt::Key_Right) : QKeySequence(Qt::SHIFT+Qt::Key_Left));
     connect(changeTabLeft, SIGNAL( triggered( bool ) ), this, SLOT( slotChangeTabLeft() ));
 
-    changeTabRight = actionCollection()->addAction("next_tab");
+    KAction* changeTabRight = actionCollection()->addAction("next_tab");
     changeTabRight->setText(QApplication::layoutDirection() ? selectTabLeftString : selectTabRightString);
     changeTabRight->setShortcut(QApplication::layoutDirection() ?
                     QKeySequence(Qt::SHIFT+Qt::Key_Left) : QKeySequence(Qt::SHIFT+Qt::Key_Right));
@@ -646,10 +671,6 @@ void UMLApp::initView()
 
     tabifyDockWidget(m_documentationDock, m_cmdHistoryDock);
     //tabifyDockWidget(m_cmdHistoryDock, m_propertyDock);
-
-    QByteArray dockConfig;
-    dockConfig += UmbrelloSettings::dockConfig().toAscii();
-    restoreState(dockConfig); //reposition all the DockWindows to their saved positions
 }
 
 void UMLApp::openDocumentFile(const KUrl& url)
@@ -761,7 +782,7 @@ void UMLApp::saveOptions()
     UmbrelloSettings::setAutoGenerateAttributeAccessorsJava(optionState.codeGenerationState.javaCodeGenerationState.autoGenerateAttributeAccessors);
     UmbrelloSettings::setAutoGenerateAssocAccessorsJava(optionState.codeGenerationState.javaCodeGenerationState.autoGenerateAssocAccessors);
 
-//     CodeGenerator *codegen = UMLApp::app()->getGenerator();
+//     CodeGenerator *codegen = getGenerator();
 //     JavaCodeGenerator *javacodegen = dynamic_cast<JavaCodeGenerator*>(codegen);
 //     if (javacodegen)
 //         UmbrelloSettings::setBuildANTDocumentJava( javacodegen->getCreateANTBuildFile());
@@ -848,8 +869,6 @@ void UMLApp::readProperties(const KConfigGroup & cfg)     //:TODO: applyMainWind
 
 bool UMLApp::queryClose()
 {
-    QByteArray dockConfig = saveState();
-    UmbrelloSettings::setDockConfig( dockConfig );
     return m_doc->saveModified();
 }
 
@@ -1040,8 +1059,6 @@ void UMLApp::slotFileQuit()
 {
     slotStatusMsg(i18n("Exiting..."));
     if (m_doc->saveModified()) {
-        QByteArray dockConfig = saveState();
-        UmbrelloSettings::setDockConfig( dockConfig );
         saveOptions();
         qApp->quit();
     }
@@ -1580,6 +1597,16 @@ CodeGenerator* UMLApp::getGenerator()
     return m_codegen;
 }
 
+bool UMLApp::isSimpleCodeGeneratorActive()
+{
+    if (m_codegen && dynamic_cast<SimpleCodeGenerator*>(m_codegen)) {
+        return true;
+    }
+    else {
+        return false;
+    }
+}
+
 void UMLApp::generateAllCode()
 {
     if (m_codegen) {
@@ -1688,11 +1715,6 @@ void UMLApp::setLang_xmlschema()
     setActiveLanguage(Uml::pl_XMLSchema);
 }
 
-void UMLApp::setLang_ocl()
-{
-    setActiveLanguage(Uml::pl_Ocl);
-}
-
 void UMLApp::setActiveLanguage(Uml::Programming_Language pl)
 {
     updateLangSelectMenu(pl);
@@ -1822,7 +1844,7 @@ void UMLApp::slotImportClasses()
     if (pl == Uml::pl_IDL) {
         preselectedExtension = i18n("*.idl|IDL Files (*.idl)");
     } else if (pl == Uml::pl_Python) {
-        preselectedExtension = i18n("*.py|Python Files (*.py)");
+        preselectedExtension = i18n("*.py|Python Files (*.py *.pyw)");
     } else if (pl == Uml::pl_Java) {
         preselectedExtension = i18n("*.java|Java Files (*.java)");
     } else if (pl == Uml::pl_Pascal) {
@@ -1834,7 +1856,7 @@ void UMLApp::slotImportClasses()
     }
     preselectedExtension.append("\n*|" + i18n("All Files"));
 #ifdef Q_WS_WIN
-    QStringList extList = preselectedExtension.split("|");
+    QStringList extList = preselectedExtension.split('|');
     QStringList fileList = QFileDialog::getOpenFileNames(this, i18n("Select Code to Import"),    //krazy:exclude=qclasses
                                 "", extList[1] );
 #else
@@ -1934,7 +1956,7 @@ void UMLApp::initGenerator()
 void UMLApp::updateLangSelectMenu(Uml::Programming_Language activeLanguage)
 {
     //m_langSelect->clear();
-    for (int i = 0; i < Uml::pl_Reserved; i++) {
+    for (int i = 0; i < Uml::pl_Reserved; ++i) {
         m_langAct[i]->setChecked(i == activeLanguage);
     }
 }
@@ -2237,8 +2259,8 @@ void UMLApp::executeCommand(QUndoCommand* cmd)
 {
     if (cmd != NULL) {
         m_pUndoStack->push(cmd);
+        uDebug() << cmd->text() << " [" << m_pUndoStack->count() << "]";
     }
-    uDebug() << cmd->text() << " [" << m_pUndoStack->count() << "]";
 
     UMLApp::app()->enableUndo(true);
 }
